==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/mailconf/mailconf.pm <==
/* _dict.cc 14/08/1996 15.04.54 */
/* alias.cc 12/12/1999 22.30.32 */
PUBLIC ALIAS::ALIAS (void);
PUBLIC void ALIAS::addoneval (const char *val);
PRIVATE void ALIAS::splitline (char *ptpt);
PUBLIC ALIAS::ALIAS (char *line);
PUBLIC const char *ALIAS::getname (void);
PUBLIC int ALIAS::filter_ok (void);
PUBLIC int ALIAS::file_ok (void);
PUBLIC void ALIAS::write (FILE *fout);
PUBLIC int ALIAS::is_valid (void);
PUBLIC int ALIAS::edit (PRIVILEGE *privi);
PUBLIC ALIAS *ALIASES::getitem (int no);
PRIVATE void ALIASES::addline (char *buf);
PUBLIC ALIASES::ALIASES (CONFIG_FILE&_f,
	 PRIVILEGE *_privi,
	 bool _dodb);
PUBLIC int ALIASES::write (void);
PUBLIC int ALIASES::locate (const char *name);
PUBLIC void ALIASES::addnew (void);
PUBLIC int ALIASES::edit (const char *title);
PUBLIC int ALIASES::setalias (const char *name,
	 int nb,
	 const char *vals[]);
PUBLIC void ALIAS::removesome (const char *vals[], int nb);
PUBLIC int ALIASES::unsetalias (const char *name,
	 int nb,
	 const char *vals[]);
/* aliascomng.cc 12/12/1999 22.22.16 */
PRIVATE void ALIAS_COMNG::setup_uquotap (char uquotap[PATH_MAX]);
PUBLIC ALIAS_COMNG::ALIAS_COMNG (DICTIONARY&_dict);
PUBLIC void ALIAS_COMNG::setupdia (DIALOG&dia);
PUBLIC int ALIAS_COMNG::save (PRIVILEGE *priv);
PUBLIC int ALIAS_COMNG::validate (DIALOG&, int &nof);
PUBLIC int ALIAS_COMNG::deluser (PRIVILEGE *priv);
/* basic.cc 12/12/1999 22.12.46 */
PUBLIC int MAILCONF::basicedit (void);
PUBLIC int MAILCONF::check (VDOMAINS&vdoms);
/* complex.cc 01/06/1999 11.21.16 */
PUBLIC COMPLEX_ROUTE::COMPLEX_ROUTE (const char *buf);
PUBLIC COMPLEX_ROUTE::COMPLEX_ROUTE (void);
PUBLIC int COMPLEX_ROUTE::edit (void);
PUBLIC COMPLEX_ROUTES::COMPLEX_ROUTES (void);
PUBLIC COMPLEX_ROUTE *COMPLEX_ROUTES::getitem (int no);
PUBLIC int COMPLEX_ROUTES::write (void);
PUBLIC int COMPLEX_ROUTES::edit (void);
PUBLIC int COMPLEX_ROUTE::rule0 (FILE *fout,
	 char *status,
	 SSTRINGS *aliases,
	 VDOMAINS *vdomains);
PUBLIC bool COMPLEX_ROUTE::isuserroute (void);
PUBLIC int COMPLEX_ROUTES::rule0 (FILE *fout,
	 SSTRINGS&aliases,
	 VDOMAINS&vdomains);
/* confread.cc 13/12/1999 21.53.12 */
PUBLIC MAILCONF::MAILCONF (void);
PUBLIC int MAILCONF::write (void);
PUBLIC int MAILCONF::getqueuedelay (void);
/* generate.cc 17/02/2000 00.38.22 */
PUBLIC MAILCONF_FILE::MAILCONF_FILE (const char *fname);
PRIVATE int MAILCONF::generate (FILE *fout);
PRIVATE bool MAILCONF::generated_byme (char sendmail_sum[]);
PUBLIC int MAILCONF::generate_go (bool confirm);
PUBLIC int MAILCONF::generate (bool confirm);
PUBLIC int MAILCONF::generate_if (bool confirm);
/* helpf.cc 14/08/1996 15.06.34 */
PUBLIC MAILCONF_HELP_FILE::MAILCONF_HELP_FILE (const char *fname);
/* internal.cc 17/11/1997 14.30.36 */
/* mailconf.cc 17/02/2000 00.38.46 */
PUBLIC void MAILCONF::spcs_edit (void);
/* mailfax.cc 20/12/1998 14.44.00 */
PUBLIC FAXALIAS::FAXALIAS (const char *buf);
PUBLIC FAXALIAS::FAXALIAS (void);
PUBLIC int FAXALIAS::edit (void);
PUBLIC FAXALIASES::FAXALIASES (void);
PUBLIC int FAXALIASES::write (void);
PUBLIC FAXALIAS *FAXALIASES::getitem (int no);
PUBLIC int FAXALIASES::edit (void);
PUBLIC FAXUSER::FAXUSER (const char *buf);
PUBLIC FAXUSER::FAXUSER (void);
PUBLIC int FAXUSER::edit (void);
PUBLIC FAXUSERS::FAXUSERS (void);
PUBLIC int FAXUSERS::write (void);
PUBLIC FAXUSER *FAXUSERS::getitem (int no);
PUBLIC int FAXUSERS::edit (void);
PUBLIC const char *FAXRULE::getid (void);
PRIVATE void FAXRULE::init (void);
PUBLIC FAXRULE::FAXRULE (CONFDB&db, const char *id);
PUBLIC FAXRULE::FAXRULE (void);
PUBLIC void FAXRULE::write (CONFDB&db);
PUBLIC FAXRULES::FAXRULES (void);
PUBLIC int FAXRULES::write (void);
PUBLIC FAXRULE *FAXRULES::getitem (int no);
PUBLIC int FAXRULE::edit (void);
PUBLIC int FAXRULES::edit (void);
PRIVATE void FAXZONE::init (void);
PUBLIC FAXZONE::FAXZONE (const char *buf);
PUBLIC FAXZONE::FAXZONE (void);
PUBLIC FAXZONES::FAXZONES (void);
PUBLIC int FAXZONES::write (void);
PUBLIC FAXZONE *FAXZONES::getitem (int no);
PUBLIC int FAXZONE::edit (void);
PUBLIC int FAXZONES::edit (void);
PUBLIC MAILFAX::MAILFAX (void);
PUBLIC int MAILFAX::write (void);
PUBLIC int MAILFAX::edit (void);
/* mailq.cc 13/07/1999 18.28.22 */
PUBLIC MAILQ_ENTRY::MAILQ_ENTRY (const char *_id,
	 int _size,
	 const char *_date,
	 const char *_sender);
PUBLIC int MAILQ_ENTRY::edit (void);
PUBLIC MAILQ_ENTRY *MAILQ_ENTRIES::getitem (int no)const;
/* masq.cc 03/03/1999 09.43.54 */
PUBLIC MASQ::MASQ (const char *buf);
PUBLIC MASQ::MASQ (void);
PUBLIC int MASQ::edit (void);
PUBLIC MASQS::MASQS (void);
PUBLIC MASQ *MASQS::getitem (int no);
PUBLIC int MASQS::write (void);
PUBLIC int MASQS::edit (void);
PUBLIC int MASQ::rule1 (FILE *fout, char *status);
PUBLIC int MASQS::rule1 (FILE *fout);
/* mod_mailconf.cc 17/02/2000 00.38.34 */
PUBLIC MODULE_mailconf::MODULE_mailconf (void);
PUBLIC void MODULE_mailconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_mailconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_mailconf::dohtml (const char *key);
PUBLIC int MODULE_mailconf::message (const char *msg,
	 int ,
	 const char *argv[]);
PUBLIC int MODULE_mailconf::probe (int level, int target, bool);
PUBLIC void MODULE_mailconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_mailconf::execmain (int argc, char *argv[]);
/* mtable.cc 08/02/2000 17.20.36 */
PUBLIC SPC_ROUTE::SPC_ROUTE (void);
PUBLIC void SPC_ROUTE::write (FILE *fout);
PUBLIC int SPC_ROUTE::edit (void);
PUBLIC SPC_ROUTES::SPC_ROUTES (void);
PUBLIC int SPC_ROUTES::save (void);
PUBLIC int SPC_ROUTES::build (void);
PUBLIC SPC_ROUTE *SPC_ROUTES::getitem (int no);
PUBLIC void SPC_ROUTES::sort (void);
PUBLIC int SPC_ROUTES::edit (void);
/* spam.cc 20/12/1998 14.44.56 */
PUBLIC SPAM_ITEM::SPAM_ITEM (const char *line);
PUBLIC VIRTUAL int SPAM_ITEM::edit (const char *title,
	 const char *intro,
	 const char *field);
PUBLIC VIRTUAL SPAM_ITEM *SPAM_ITEMS::new_spam_item (const char *line);
PUBLIC SPAM_ITEMS::SPAM_ITEMS (CONFIG_FILE&_fconf);
PRIVATE void SPAM_ITEMS::read (void);
PUBLIC SPAM_ITEM *SPAM_ITEMS::getitem (int no)const;
PUBLIC VIRTUAL int SPAM_ITEM::write (FILE *fout);
PUBLIC VIRTUAL void SPAM_ITEM::format (char buf1[100],
	 char buf2[100]);
PUBLIC int SPAM_ITEMS::write (void);
PUBLIC int SPAM_ITEMS::edit (const char *title,
	 const char *intro,
	 const char *head,
	 const char *subtitle,
	 const char *subintro,
	 const char *subfield);
PUBLIC int SPAM_ITEM_DENY::write (FILE *fout);
PUBLIC void SPAM_ITEM_DENY::format (char buf1[100],
	 char buf2[100]);
PUBLIC SPAM_ITEM_DENY::SPAM_ITEM_DENY (const char *line);
PUBLIC int SPAM_ITEM_DENY::edit (const char *,
	 const char *,
	 const char *);
PUBLIC SPAM_ITEM *SPAM_ITEMS_DENY::new_spam_item (const char *line);
PUBLIC SPAM_ITEMS_DENY::SPAM_ITEMS_DENY (CONFIG_FILE&_fconf);
PUBLIC int SPAM_ITEMS_DENY::write (void);
/* vdomain.cc 06/01/2000 00.09.34 */
PUBLIC VDOMAIN::VDOMAIN (const char *line);
PUBLIC VDOMAIN::VDOMAIN (void);
PRIVATE void VDOMAIN::showother (DIALOG&dia, int item);
PRIVATE void VDOMAIN::addother (DIALOG&dia);
PUBLIC void VDOMAIN::setupdia (DIALOG&dia);
PUBLIC int VDOMAIN::edit (VDOMAINS&vs);
PUBLIC void VDOMAIN::setpwdpaths (char *pwdfile,
	 char *shadowfile,
	 char *pathhome,
	 char *root);
PUBLIC void VDOMAINS::sort (void);
PUBLIC VDOMAIN *VDOMAINS::getitem (int no);
PUBLIC VDOMAIN *VDOMAINS::getitem (const char *domain);
PUBLIC VDOMAINS::VDOMAINS (void);
PUBLIC VDOMAIN *VDOMAINS::lookup (const char *str);
PUBLIC int VDOMAINS::write (void);
PUBLIC void VDOMAIN::createfiles (void);
PUBLIC int VDOMAINS::edit (void);
int FIXPERM_VDOMAIN::check (bool boottime, bool silentflag);
void FIXPERM_VDOMAIN::list (FIXPERM_SPECS&specs);
PUBLIC void VDOMAINS::listperm (FIXPERM_SPECS&specs);
PUBLIC VDOMAIN *VDOMAINS::locate (const char *domain);
PUBLIC int VDOMAINS::checkperm (bool, bool);
PUBLIC USERS *VDOMAIN::getusers (CONFIG_FILE *&file,
	 CONFIG_FILE *&file_shadow);
PUBLIC MENU_STATUS VDOMAINS::select (const char *title,
	 const char *intro,
	 int mayadd,
	 int &nof);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC VIRTUAL_COMNG::~VIRTUAL_COMNG (void);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/mailconf/mailconf.pm <==
/* _dict.cc 14/08/1996 15.04.54 */
/* alias.cc 09/03/2001 15.06.12 */
PUBLIC ALIAS::ALIAS (void);
PUBLIC void ALIAS::addoneval (const char *val);
PRIVATE void ALIAS::splitline (char *ptpt);
PUBLIC ALIAS::ALIAS (const char *line);
PUBLIC const char *ALIAS::getname (void);
PUBLIC int ALIAS::filter_ok (void);
PUBLIC int ALIAS::file_ok (void);
PUBLIC void ALIAS::write (FILE_CFG *fout);
PUBLIC int ALIAS::is_valid (void);
PUBLIC bool ALIASES::isdup (ALIAS *ali);
PUBLIC int ALIAS::edit (PRIVILEGE *privi, ALIASES&aliases);
PUBLIC ALIAS *ALIASES::getitem (int no);
PRIVATE void ALIASES::addline (SSTRING&buf);
PUBLIC ALIASES::ALIASES (CONFIG_FILE&_f,
	 PRIVILEGE *_privi,
	 bool _dodb);
PUBLIC int ALIASES::write (void);
PUBLIC int ALIASES::locate (const char *name);
PUBLIC void ALIASES::addnew (void);
PUBLIC int ALIASES::edit (const char *title);
PUBLIC int ALIASES::setalias (const char *name,
	 int nb,
	 const char *vals[]);
PUBLIC void ALIAS::removesome (const char *vals[], int nb);
PUBLIC int ALIASES::unsetalias (const char *name,
	 int nb,
	 const char *vals[]);
/* aliascomng.cc 03/03/2000 12.49.36 */
PRIVATE void ALIAS_COMNG::setup_uquotap (char uquotap[PATH_MAX]);
PUBLIC ALIAS_COMNG::ALIAS_COMNG (DICTIONARY&_dict);
PUBLIC void ALIAS_COMNG::setupdia (DIALOG&dia);
PUBLIC int ALIAS_COMNG::save (PRIVILEGE *priv);
PUBLIC int ALIAS_COMNG::validate (DIALOG&, int &nof);
PUBLIC int ALIAS_COMNG::deluser (PRIVILEGE *priv);
/* basic.cc 05/03/2001 15.17.58 */
PUBLIC int MAILCONF::basicedit (void);
PUBLIC int MAILCONF::check (VDOMAINS&vdoms);
/* complex.cc 07/08/2000 13.51.18 */
PUBLIC COMPLEX_ROUTE::COMPLEX_ROUTE (const char *buf);
PUBLIC COMPLEX_ROUTE::COMPLEX_ROUTE (void);
PUBLIC int COMPLEX_ROUTE::edit (void);
PUBLIC COMPLEX_ROUTES::COMPLEX_ROUTES (void);
PUBLIC COMPLEX_ROUTE *COMPLEX_ROUTES::getitem (int no);
PUBLIC int COMPLEX_ROUTES::write (void);
PUBLIC int COMPLEX_ROUTES::edit (void);
PUBLIC int COMPLEX_ROUTE::rule0 (SSTREAM&out,
	 char *status,
	 SSTRINGS *aliases,
	 VDOMAINS *vdomains);
PUBLIC bool COMPLEX_ROUTE::isuserroute (void);
PUBLIC int COMPLEX_ROUTES::rule0 (SSTREAM&out,
	 SSTRINGS&aliases,
	 VDOMAINS&vdomains);
/* confread.cc 05/03/2001 15.07.34 */
PUBLIC MAILCONF::MAILCONF (void);
PUBLIC int MAILCONF::write (void);
PUBLIC int MAILCONF::getqueuedelay (void);
/* generate.cc 05/03/2001 22.00.36 */
PUBLIC MAILCONF_FILE::MAILCONF_FILE (const char *fname);
PRIVATE int MAILCONF::format (SSTREAM&out);
PRIVATE bool MAILCONF::generated_byme (char sendmail_sum[]);
PUBLIC int MAILCONF::generate_go (bool confirm);
PUBLIC int MAILCONF::generate (bool confirm);
PUBLIC int MAILCONF::generate_if (bool confirm);
/* helpf.cc 14/08/1996 15.06.34 */
PUBLIC MAILCONF_HELP_FILE::MAILCONF_HELP_FILE (const char *fname);
/* internal.cc 17/11/1997 14.30.36 */
/* mailconf.cc 05/03/2001 15.13.40 */
PUBLIC void MAILCONF::spcs_edit (void);
/* mailfax.cc 07/08/2000 00.35.16 */
PUBLIC FAXALIAS::FAXALIAS (const char *buf);
PUBLIC FAXALIAS::FAXALIAS (void);
PUBLIC int FAXALIAS::edit (void);
PUBLIC FAXALIASES::FAXALIASES (void);
PUBLIC int FAXALIASES::write (void);
PUBLIC FAXALIAS *FAXALIASES::getitem (int no);
PUBLIC int FAXALIASES::edit (void);
PUBLIC FAXUSER::FAXUSER (const char *buf);
PUBLIC FAXUSER::FAXUSER (void);
PUBLIC int FAXUSER::edit (void);
PUBLIC FAXUSERS::FAXUSERS (void);
PUBLIC int FAXUSERS::write (void);
PUBLIC FAXUSER *FAXUSERS::getitem (int no);
PUBLIC int FAXUSERS::edit (void);
PUBLIC const char *FAXRULE::getid (void);
PRIVATE void FAXRULE::init (void);
PUBLIC FAXRULE::FAXRULE (CONFDB&db, const char *id);
PUBLIC FAXRULE::FAXRULE (void);
PUBLIC void FAXRULE::write (CONFDB&db);
PUBLIC FAXRULES::FAXRULES (void);
PUBLIC int FAXRULES::write (void);
PUBLIC FAXRULE *FAXRULES::getitem (int no);
PUBLIC int FAXRULE::edit (void);
PUBLIC int FAXRULES::edit (void);
PRIVATE void FAXZONE::init (void);
PUBLIC FAXZONE::FAXZONE (const char *buf);
PUBLIC FAXZONE::FAXZONE (void);
PUBLIC FAXZONES::FAXZONES (void);
PUBLIC int FAXZONES::write (void);
PUBLIC FAXZONE *FAXZONES::getitem (int no);
PUBLIC int FAXZONE::edit (void);
PUBLIC int FAXZONES::edit (void);
PUBLIC MAILFAX::MAILFAX (void);
PUBLIC int MAILFAX::write (void);
PUBLIC int MAILFAX::edit (void);
/* mailq.cc 16/10/2000 17.40.34 */
PUBLIC MAILQ_ENTRY::MAILQ_ENTRY (const char *_id,
	 int _size,
	 const char *_date,
	 const char *_sender);
PUBLIC int MAILQ_ENTRY::edit (void);
PUBLIC MAILQ_ENTRY *MAILQ_ENTRIES::getitem (int no)const;
/* masq.cc 07/08/2000 13.56.16 */
PUBLIC MASQ::MASQ (const char *buf);
PUBLIC MASQ::MASQ (void);
PUBLIC int MASQ::edit (void);
PUBLIC MASQS::MASQS (void);
PUBLIC MASQ *MASQS::getitem (int no);
PUBLIC int MASQS::write (void);
PUBLIC int MASQS::edit (void);
PUBLIC int MASQ::rule1 (SSTREAM&out, char *status);
PUBLIC int MASQS::rule1 (SSTREAM&out);
/* mod_mailconf.cc 28/08/2000 18.13.26 */
PUBLIC MODULE_mailconf::MODULE_mailconf (void);
PUBLIC void MODULE_mailconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_mailconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_mailconf::dohtml (const char *key);
PUBLIC int MODULE_mailconf::message (const char *msg,
	 int ,
	 const char *argv[]);
PUBLIC int MODULE_mailconf::probe (int level, int target, bool);
PUBLIC void MODULE_mailconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_mailconf::execmain (int argc, char *argv[], bool);
/* mtable.cc 07/08/2000 00.36.00 */
PUBLIC SPC_ROUTE::SPC_ROUTE (void);
PUBLIC void SPC_ROUTE::write (FILE_CFG *fout);
PUBLIC int SPC_ROUTE::edit (void);
PUBLIC SPC_ROUTES::SPC_ROUTES (void);
PUBLIC int SPC_ROUTES::save (void);
PUBLIC int SPC_ROUTES::build (void);
PUBLIC SPC_ROUTE *SPC_ROUTES::getitem (int no);
PUBLIC void SPC_ROUTES::sort (void);
PUBLIC int SPC_ROUTES::edit (void);
/* popauth.cc 26/09/2000 00.53.14 */
/* sendmail-check.cc 12/02/2001 17.48.32 */
/* spam.cc 28/09/2000 16.40.16 */
PUBLIC SPAM_ITEM::SPAM_ITEM (const char *line);
PUBLIC VIRTUAL int SPAM_ITEM::edit (const char *title,
	 const char *intro,
	 const char *field);
PUBLIC VIRTUAL SPAM_ITEM *SPAM_ITEMS::new_spam_item (const char *line);
PUBLIC SPAM_ITEMS::SPAM_ITEMS (CONFIG_FILE&_fconf);
PRIVATE void SPAM_ITEMS::read (void);
PUBLIC SPAM_ITEM *SPAM_ITEMS::getitem (int no)const;
PUBLIC VIRTUAL int SPAM_ITEM::write (FILE_CFG *fout);
PUBLIC VIRTUAL void SPAM_ITEM::format (char buf1[100],
	 char buf2[100]);
PUBLIC int SPAM_ITEMS::write (void);
PUBLIC int SPAM_ITEMS::edit (const char *title,
	 const char *intro,
	 const char *head,
	 const char *subtitle,
	 const char *subintro,
	 const char *subfield);
PUBLIC int SPAM_ITEM_DENY::write (FILE_CFG *fout);
PUBLIC void SPAM_ITEM_DENY::format (char buf1[100],
	 char buf2[100]);
PUBLIC SPAM_ITEM_DENY::SPAM_ITEM_DENY (const char *line);
PUBLIC int SPAM_ITEM_DENY::edit (const char *,
	 const char *,
	 const char *);
PUBLIC SPAM_ITEM *SPAM_ITEMS_DENY::new_spam_item (const char *line);
PUBLIC SPAM_ITEMS_DENY::SPAM_ITEMS_DENY (CONFIG_FILE&_fconf);
PUBLIC int SPAM_ITEMS_DENY::write (void);
/* vdomain.cc 19/09/2000 10.59.36 */
PUBLIC VDOMAIN::VDOMAIN (const char *line);
PUBLIC VDOMAIN::VDOMAIN (void);
PRIVATE void VDOMAIN::showother (DIALOG&dia, int item);
PRIVATE void VDOMAIN::addother (DIALOG&dia);
PUBLIC void VDOMAIN::setupdia (DIALOG&dia);
PRIVATE void VDOMAIN::renameold (const char *prefix);
PUBLIC int VDOMAIN::edit (VDOMAINS&vs);
PUBLIC void VDOMAIN::setpwdpaths (char *pwdfile,
	 char *shadowfile,
	 char *pathhome,
	 char *root);
PUBLIC void VDOMAINS::sort (void);
PUBLIC VDOMAIN *VDOMAINS::getitem (int no)const;
PUBLIC VDOMAIN *VDOMAINS::getitem (const char *domain)const;
PUBLIC VDOMAINS::VDOMAINS (void);
PUBLIC VDOMAIN *VDOMAINS::lookup (const char *str)const;
PUBLIC int VDOMAINS::lookup (VDOMAIN *pt)const;
PUBLIC int VDOMAINS::write (void);
PUBLIC void VDOMAIN::createfiles (void);
PUBLIC int VDOMAINS::edit (void);
int FIXPERM_VDOMAIN::check (bool boottime, bool silentflag);
void FIXPERM_VDOMAIN::list (FIXPERM_SPECS&specs);
PUBLIC void VDOMAINS::listperm (FIXPERM_SPECS&specs);
PUBLIC VDOMAIN *VDOMAINS::locate (const char *domain);
PUBLIC int VDOMAINS::checkperm (bool, bool);
PUBLIC USERS *VDOMAIN::getusers (CONFIG_FILE *&file,
	 CONFIG_FILE *&file_shadow);
PUBLIC MENU_STATUS VDOMAINS::select (DIALOG_LISTE&dia,
	 const char *title,
	 const char *intro,
	 int mayadd,
	 int &nof);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC VIRTUAL_COMNG::~VIRTUAL_COMNG (void);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);
